TopologicalEncoder - LatentLego

Skip to content

# TopologicalEncoder

### `latent.modules.encoder.TopologicalEncoder`

Encoder model with topological regularization loss on latent space (Moor 2019).

#### `__init__(self, latent_dim=50, name='topological_encoder', initializer='glorot_normal', topo_weight=1.0, **kwargs)` `special`

Parameters:

Name | Type | Description | Default
--- | --- | --- | ---
`latent_dim` | `int` | Integer indicating the number of dimensions in the latent space. | `50`
`name` | `str` | String indicating the name of the model. | `'topological_encoder'`
`initializer` | `Union[str, Callable]` | Initializer for the kernel weights matrix (see `keras.initializers`) | `'glorot_normal'`
`topo_weight` | `float` | Float indicating the weight of the topological loss. | `1.0`
`**kwargs` | `` | Other arguments passed on to `DenseStack` | `{}`